@@ -5,6 +5,7 @@ import logging
 import re
 from datetime import date
 from datetime import datetime as dt
+from datetime import timedelta
 from typing import Any, Optional, Tuple
 
 import pandas as pd
@@ -25,6 +26,7 @@ class EnedisAnalytics:
         self,
         convertKwh: bool = False,
         convertUTC: bool = False,
+        start_date: str | None = None,
         intervals: list[Tuple[dt, dt]] | None = None,
         groupby: str | None = None,
         freq: str = "H",
@@ -32,8 +34,24 @@ class EnedisAnalytics:
         cumsum: float = 0,
     ) -> Any:
         """Convert datas to analyze."""
+        if not self.df.empty:
+            if convertUTC:
+                self.df["date"] = pd.to_datetime(
+                    self.df["date"], utc=True, format="%Y-%m-%d %H:%M:%S"
+                )
+            else:
+                self.df["date"] = pd.to_datetime(
+                    self.df["date"], utc=False, format="%Y-%m-%d %H:%M:%S"
+                )
+
+            self.df["date"] = self.df["date"].transform(self._midnightminus)
+
+            if start_date:
+                self.df = self.df[(self.df["date"] > f"{start_date} 23:59:59")]
+
         if self.df.empty:
             return self.df.to_dict(orient="records")
+
         if convertKwh:
             self.df["interval_length"] = self.df["interval_length"].transform(
                 self._weighted_interval
@@ -41,18 +59,11 @@ class EnedisAnalytics:
             self.df["value"] = (
                 pd.to_numeric(self.df["value"]) / 1000 * self.df["interval_length"]
             )
-        if convertUTC:
-            self.df["date"] = pd.to_datetime(
-                self.df["date"], utc=True, format="%Y-%m-%d %H:%M:%S"
-            )
 
         if intervals:
-            resultat = self._get_data_interval(
-                intervals, groupby, freq, summary, cumsum
-            )
-            return resultat[0].to_dict("records"), resultat[1].to_dict("records")
-        else:
-            return self.df.to_dict(orient="records")
+            self.df = self._get_data_interval(intervals, groupby, freq, summary, cumsum)
+
+        return self.df.to_dict(orient="records")
 
     def _weighted_interval(self, interval: str) -> float | int:
         """Compute weighted."""
@@ -60,6 +71,16 @@ class EnedisAnalytics:
             return int(rslt[0]) / 60
         return 1
 
+    def _midnightminus(self, date: dt) -> dt:
+        """Subtracts one minute.
+
+        to avoid taking midnight on the next day
+        """
+        if date.time() == dt.strptime("00:00:00", "%H:%M:%S").time():
+            date = date - timedelta(minutes=1)
+            return date
+        return date
+
     def _get_data_interval(
         self,
         intervalls: list[Tuple[dt, dt]],
@@ -68,41 +89,27 @@ class EnedisAnalytics:
         summary: bool = False,
         cumsum: float = 0,
     ) -> pd.DataFrame:
-        """Group date from range time.
-
-        Returns a tuple
-        First dict contains the data in the interval
-        and the second dict contains the data outside
-        """
+        """Group date from range time."""
         in_df = pd.DataFrame()
         for intervall in intervalls:
+            start = intervall[0].time()
+            end = self._midnightminus(intervall[1]).time()
             df2 = self.df[
-                (self.df.date.dt.time >= intervall[0].time())
-                & (self.df.date.dt.time < intervall[1].time())
+                (self.df.date.dt.time > start) & (self.df.date.dt.time <= end)
             ]
             in_df = pd.concat([in_df, df2], ignore_index=True)
 
-        # out_df = self.df[~self.df.isin(in_df)].dropna()
-
         if groupby:
             in_df = (
-                in_df.groupby(pd.Grouper(key="date", freq="H"))["value"]
+                in_df.groupby(pd.Grouper(key="date", freq=freq))["value"]
                 .sum()
                 .reset_index()
             )
             in_df = in_df[in_df.value != 0]
 
-            # out_df = (
-            #     out_df.groupby(pd.Grouper(key="date", freq="H"))["value"]
-            #     .sum()
-            #     .reset_index()
-            # )
-
         if summary:
             in_df["sum_value"] = in_df.value.cumsum() + cumsum
-            # out_df["sum_value"] = out_df.value.cumsum() + cumsum
 
-        # return in_df, out_df
         return in_df
 
     def set_price(
@@ -120,6 +127,13 @@ class EnedisAnalytics:
             df["sum_price"] = df["price"].cumsum()
         return df.to_dict("records")
 
+    def get_last_value(self, data: dict[str, Any], orderby: str, value: str) -> Any:
+        """Return last value after order by."""
+        df = pd.DataFrame(data)
+        if not df.empty:
+            df = df.sort_values(by=orderby)
+            return df[value].iloc[-1]
+
 
 class EnedisByPDL:
     """Get data of pdl."""
